<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>ConfigureHID</name>
    <message>
        <location filename="configurehid.ui" line="33"/>
        <source>Configure HID Plugin</source>
        <translation>Configurar el Plugin HID</translation>
    </message>
    <message>
        <location filename="configurehid.ui" line="52"/>
        <source>Input Line</source>
        <translation>Línea de Entrada</translation>
    </message>
    <message>
        <location filename="configurehid.ui" line="57"/>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <location filename="configurehid.ui" line="62"/>
        <source>Merger Mode</source>
        <translation>Modo Fusión</translation>
    </message>
    <message>
        <location filename="configurehid.ui" line="70"/>
        <source>Refresh</source>
        <translation>Actualizar</translation>
    </message>
</context>
<context>
    <name>HIDDMXDevice</name>
    <message>
        <location filename="hiddmxdevice.cpp" line="62"/>
        <source>HID DMX Interface Error</source>
        <translation>Error de Interfaz HID DMX</translation>
    </message>
    <message>
        <location filename="hiddmxdevice.cpp" line="63"/>
        <source>Unable to open %1. Make sure the udev rule is installed.</source>
        <translation>No es posible abrir %1. Asegúrese que la regla udev está instalada.</translation>
    </message>
</context>
<context>
    <name>HIDJsDevice</name>
    <message>
        <location filename="hidjsdevice.cpp" line="116"/>
        <source>Axes: %1</source>
        <translation>Ejes: %1</translation>
    </message>
    <message>
        <location filename="hidjsdevice.cpp" line="118"/>
        <source>Buttons: %1</source>
        <translation>Botones: %1</translation>
    </message>
</context>
<context>
    <name>HIDPlugin</name>
    <message>
        <location filename="hidplugin.cpp" line="125"/>
        <source>This plugin provides support for HID-based joysticks, gamepads and some USB DMX adapters.</source>
        <translation>Este plugin provee soporte para joysticks, game pads y algunos adaptadores USB DMX basados en HID.</translation>
    </message>
</context>
</TS>
